/*
 * This file is part of firk's Common C Library
 *  charset/charset.h - charset conversions
 *
 * (c) firk 2019; firk@cantconnect.ru
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software.
 * 4. Altered versions in any form must be plainly marked as such, and
 *    must not be misinterpreted as being the original software.
 *
 * This software is provided by the author and contributors `as is'
 * without any express or implied warranty.
 */
#ifndef FCL_INCLUDED_CHARSET_H
#define FCL_INCLUDED_CHARSET_H

/*
  invmode:
   0 = keep invalid input "as is" (most likely producing invalid output)
   1 = replace invalid input with U+FFFD (UTF-8: EF BF BD)
   2 = skip invalid input
   in all cases, return value changed from 0 to 3 when invalid input occured
  u_flags (only meaningful for unicode charsets)
   treat certain Unicode indexes as invalid input (=> see invmode)
   note that invmode==0 may do some mess against this option
   1 = non-characters (FDD0..FDEF FFFE, FFFF, xxFFFE, xxFFFF)
   2 = surrogate characters (D800 .. DFFF)
   4 = private-use (E000..F8FF F0000..FFFFD 100000..10FFFD)
   8 = out-of-range (>10FFFF)
   16 = overlong utf-8 sequences (ex. C0 80)
   other flags:
   32 = normalize overlong sequences into canonical ones
  ascii_bl[16] (used incompletely is invmode==0, may randomly ignore this list)
   blacklist of codes 0..127 from decoding directly
   may be NULL ( = all zeros)
   blacklisted ascii-code will be stored as 0xC0/0xC1 0x80..0xBF sequences
   instead of raw bytes
  return:
   0 = ok
   1 = unknown charset
   2 = not enough place in dest
   3 = invalid characters for specified charset, but tried to recover
      example: >=128 for us-ascii ot wrong utf-8 sequence
 */

extern unsigned charset_to_utf8(uchar const * src, size_t slen, uchar * dest,
                size_t dsz, size_t * rsz, uchar const * charset, int invmode,
                int u_flags, uchar const * ascii_bl);

#endif

