/*
 * This file is part of firk's Common C Library
 *  conio/conio.h - interactive console i/o
 *
 * (c) firk 2015, 2022; firk@cantconnect.ru
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software.
 * 4. Altered versions in any form must be plainly marked as such, and
 *    must not be misinterpreted as being the original software.
 *
 * This software is provided by the author and contributors `as is'
 * without any express or implied warranty.
 */
#ifndef FCL_INCLUDED_CONIO_H
#define FCL_INCLUDED_CONIO_H

#ifndef EOF
#define EOF (-1)
#endif

#define Black      0
#define Blue       1
#define Green      2
#define Cyan       3
#define Red        4
#define Magenta    5
#define Brown      6
#define LightGray  7
#define DarkGray   8
#define LightBlue  9
#define LightGreen 10
#define LightCyan  11
#define LightRed   12
#define Pink       13
#define Yellow     14
#define White      15
#define Blink      128

#include "keycodes.h"

/* initialize character mode terminal;
   -1 on error (tcgetattr()/tcsetattr()); errno set by that functions */
int conio_init(void);

/* rollback terminal and console settings;
   -1 on error (tcsetattr()) with errno set */
int conio_restore(void);

/* enable/disable special cbreak handling (convert some input
   characters to signals); -1 on error, same as conio_init;
   default is disabled */
int setcbreak(int enable);

/* -1=error from ioctl(), errno set; 0=ok */
int get_screensize(unsigned short * x, unsigned short * y);
int set_screensize(unsigned short x, unsigned short y);

/* 1=some pressed; 0=nothing pressed or error; errno undefined */
int keypressed(void);

/* -1=eof or error; >=0 - character from input; errno undefined */
/*int getch_raw(void);*/
int getch(void);

/* -1=error; c - ok; errno undefined */
/* putch_raw() prints raw low-order byte of c to stdout */
int putch_raw(int c);
/* putch() prints c to stdout wisely, avoiding any special handling */
int putch(int c);

/* getch() with echo; failures while sending echo doesn't get reported */
int getche(void);

/* print string; return 0=ok; -1=any error, string may be partially printed */
int cputs(char const * s);

/* manage cursor position and colors; any errors silently ignored */
void gotoxy(unsigned short x, unsigned short y);
void gotox(unsigned short x);
void clrscr(void);
void clreol(void);
void clrline(void);
void textcolor(int color);
void textbackground(int color);
void textcolors(int fg, int bg);

#endif

