/*
 * This file is part of firk's Common C Library
 *  inifile.h - .ini files reader
 *
 * (c) firk 2015; firk@cantconnect.ru
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software.
 * 4. Altered versions in any form must be plainly marked as such, and
 *    must not be misinterpreted as being the original software.
 *
 * This software is provided by the author and contributors `as is'
 * without any express or implied warranty.
 */
#ifndef FCL_INCLUDED_INIFILE_H
#define FCL_INCLUDED_INIFILE_H
typedef int (*fcl_inifile_newsection_func)(char const * fn, unsigned int ln,
            void * udata, char const * secname);
typedef int (*fcl_inifile_option_func)(char const * fn, unsigned int ln,
            void * udata, char const * secname,
            char const * name, char const * value);

/* read and parse specified file;
   call newsec() on new sections;
   call option() on each option;
   returned <0 from any of them -> stop parsing and return -3;
   return -2 on syntax error;
   return -1 on system error (open() and read(), errno set)
   store number of processed lines to *ln;
   return 0 if parsing stopped due to EOF;

   file format:
   line separator: both \n and \r\n supported
   maximum line length: 1000, not including line separator
   all leading and trailing spaces ignored
   tabulation is parsed as space, except in-value
   lines with first non-space character ; or # are skipped
   lines with-out non-space characters are skipped
   charcodes allowed in names: A-Z, a-z, 0-9, .-_[], 0x80-0xFF
   <NAME> = sequence of at least one allowed charcodes
   <SPACE> = sequence of at least one space or tab
   <ZSPACE> = <SPACE> or empty string
   allowed lines:
   [<NAME>]
   <NAME><ZSPACE>=<ZSPACE><VALUE>
   ; or # after significant line is not qualified as comment
*/

int fcl_inifile_read(char const * filename, void * udata,
                     fcl_inifile_newsection_func newsec,
                     fcl_inifile_option_func option,
                     unsigned int * ln);

#endif

