/*
 * This file is part of firk's Common C Library
 *  malloc.h - overflow-safe versions of memory allocation funcs
 *
 * (c) firk 2019, 2020; firk@cantconnect.ru
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software.
 * 4. Altered versions in any form must be plainly marked as such, and
 *    must not be misinterpreted as being the original software.
 *
 * This software is provided by the author and contributors `as is'
 * without any express or implied warranty.
 */
#ifndef FCL_MALLOC_DEBUG
#ifndef FCL_INCLUDED_MALLOC_H
#define FCL_INCLUDED_MALLOC_H

#define fcl_malloc_debug_dump() ((void*)0)
extern void * fcl_malloc(fcl_size sz);
extern void * fcl_mallocz(fcl_size sz);
extern void * fcl_realloc(void * p, fcl_size sz);
extern void * fcl_malloc_a(fcl_size sz, fcl_size n);
extern void * fcl_mallocz_a(fcl_size sz, fcl_size n);
extern void * fcl_realloc_a(void * p, fcl_size sz, fcl_size n);
extern void fcl_free(void * p);
extern void fcl_free_c(void const * p);

extern void * fcl_reallocfree(void * p, fcl_size sz);
extern void * fcl_reallocfree_a(void * p, fcl_size sz, fcl_size n);

extern void * fcl_malloc_check(fcl_size sz);
extern void * fcl_mallocz_check(fcl_size sz);
extern void * fcl_realloc_check(void * p, fcl_size sz);
extern void * fcl_malloc_a_check(fcl_size sz, fcl_size n);
extern void * fcl_mallocz_a_check(fcl_size sz, fcl_size n);
extern void * fcl_realloc_a_check(void * p, fcl_size sz, fcl_size n);
extern void fcl_free_check(void * p);
extern void fcl_free_c_check(void const * p);

extern char * fcl_strdup(char const * st);
extern char * fcl_strndup(char const * st, fcl_size sz);
extern char * fcl_substrdup(char const * st, fcl_size sz);
extern void * fcl_memdup(void const * p0, fcl_size sz);
extern char * fcl_strdup_check(char const * st);
extern char * fcl_strndup_check(char const * st, fcl_size sz);
extern char * fcl_substrdup_check(char const * st, fcl_size sz);
extern void * fcl_memdup_check(void const * p0, fcl_size sz);

#endif
#else
#include "malloc_debug.h"
#endif

