/*
 * This file is part of firk's Common C Library
 *  recvbuf.h - receive buffer
 *
 * (c) firk 2015; firk@cantconnect.ru
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software.
 * 4. Altered versions in any form must be plainly marked as such, and
 *    must not be misinterpreted as being the original software.
 *
 * This software is provided by the author and contributors `as is'
 * without any express or implied warranty.
 */
#ifndef FCL_INCLUDED_RECVBUF_H
#define FCL_INCLUDED_RECVBUF_H

struct receive_buffer {
  unsigned char * data;
  size_t totalsize;
  size_t head;
  size_t tail;
};

int receive_buffer_set_nonblock_fd(int fd);

/* sync newly received data to buffer;
   returns:
   -1 = nothing received due to error; see errno;
    0 = nothing received due to no data or due to buffer is full;
    1 = something received;
   *nbytes always contains number of newly added data to buffer;
   nbytes can be NULL if this information isn't needed;
   it is 0 for -1 and 0 return values;
   it is >0 for 1 return value;
   error in middle of receiving treated as no-error here, just partial recv;
*/
int receive_buffer_sync(struct receive_buffer * rb, int fd, size_t * nbytes);

/* the same as receive_buffer_sync but slightly more aggressve against
   read() syscall */
int receive_buffer_sync_all(struct receive_buffer * rb, int fd,
                            size_t * nbytes);

#endif

