/*
 * This file is part of firk's Common C Library
 *  strerror.h - safe implementation for strerror()
 *
 * (c) firk 2022; firk@cantconnect.ru
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software.
 * 4. Altered versions in any form must be plainly marked as such, and
 *    must not be misinterpreted as being the original software.
 *
 * This software is provided by the author and contributors `as is'
 * without any express or implied warranty.
 */
#ifndef INCLUDED_FCL_STRERROR_H
#define INCLUDED_FCL_STRERROR_H

/*
 * This file is included from strfmt.inc, so be clean
 */

/*
 * Why this needed:
 *  Libc strerror() implementation may contain a lot of code inside,
 *  including memory allocation and possibly some config-file lookups
 *  (ex. see glibc)
 *  This is not acceptable when we trying to report some fatal error,
 *  for example about failed malloc(). So we will pre-cache all known
 *  errno's into pre-allocated array and use that strings statically.
 */
extern int fcl_strerror_reinit(void);
extern int fcl_strerror_set(int e, char const * text);
extern char const * fcl_strerror(int e);
#endif

