/*
 * This file is part of firk's Common C Library
 *  string.h - openbsd-compatible wrapper for string.h/strings.h/w.e.
 *
 * (c) firk 2019, 2022, 2023; firk@cantconnect.ru
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software.
 * 4. Altered versions in any form must be plainly marked as such, and
 *    must not be misinterpreted as being the original software.
 *
 * This software is provided by the author and contributors `as is'
 * without any express or implied warranty.
 */
#ifndef FCL_INCLUDED_STRING_H
#define FCL_INCLUDED_STRING_H

/*
 * string.tpl.h is preprocessed by ./config.sh script generating work/string.h
 * work/string.h is later used as fcl string.h include file
 */

#include <string.h>
#ifndef _OPENBSD_
#ifndef _FREEBSD_
#include <strings.h>
#endif
#endif
#define FCL_EXPLICIT_BZERO
#ifdef FCL_EXPLICIT_BZERO
extern void explicit_bzero(void * p, fcl_size len);
#endif

#define FCL_STRLCPY
#ifdef FCL_STRLCPY
extern fcl_size strlcpy(char * dest, char const * src, fcl_size dstsize);
#endif

#define FCL_STRCHRNUL
#define FCL_STRCHRNUL_GNU
#ifdef FCL_STRCHRNUL
#ifndef FCL_STRCHRNUL_GNU
extern char * fcl_strchrnul(const char * st, int c);
#undef strchrnul
#define strchrnul fcl_strchrnul
#else
#ifndef _GNU_SOURCE
extern char * fcl_strchrnul(const char * st, int c);
#undef strchrnul
#define strchrnul fcl_strchrnul
#endif
#endif
#endif

extern char * strrchrnul(const char * st, int c);
extern fcl_size strpos(char const * st, int c);
extern fcl_size strrpos(char const * st, int c);
extern fcl_size strnpos(char const * st, int c, fcl_size max);

#endif

